# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/zinginternal/onboard/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Zinginternal\\Onboard\\": "packages/zinginternal/onboard/src",
            "Zinginternal\\Onboard\\Seeders\\": "packages/zinginternal/onboard/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Zinginternal\Onboard\Providers\OnboardServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Onboard'  => Zinginternal\Onboard\Facades\Onboard::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Zinginternal\\Onboard\\Seeders\\OnboardTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Zinginternal\Onboard\Providers\OnboardServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Zinginternal\Onboard\Providers\OnboardServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Zinginternal\Onboard\Providers\OnboardServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/onboard/{modulename}

**User**

    http://path-to-route-folder/user/onboard/{modulename}

**Public**

    http://path-to-route-folder/onboards


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/onboard/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/onboard/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/onboard/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/onboard/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/onboard/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/onboard/{modulename}/{slug}
    METHOD: GET