<?php

namespace Zinginternal\Onboard\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Zinginternal\Onboard\Models\Onboard;

class OnboardPolicy
{

    /**
     * Determine if the given user can view the onboard.
     *
     * @param UserPolicyInterface $authUser
     * @param Onboard $onboard
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Onboard $onboard)
    {
        if ($authUser->canDo('onboard.onboard.view') && $authUser->isAdmin()) {
            return true;
        }

        return $onboard->user_id == user_id() && $onboard->user_type == user_type();
    }

    /**
     * Determine if the given user can create a onboard.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('onboard.onboard.create');
    }

    /**
     * Determine if the given user can update the given onboard.
     *
     * @param UserPolicyInterface $authUser
     * @param Onboard $onboard
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Onboard $onboard)
    {
        if ($authUser->canDo('onboard.onboard.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $onboard->user_id == user_id() && $onboard->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given onboard.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Onboard $onboard)
    {
        return $onboard->user_id == user_id() && $onboard->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given onboard.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Onboard $onboard)
    {
        if ($authUser->canDo('onboard.onboard.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given onboard.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Onboard $onboard)
    {
        if ($authUser->canDo('onboard.onboard.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
