<?php

namespace Zinginternal\Onboard\Providers;

use Illuminate\Support\ServiceProvider;
use Zinginternal\Onboard\Onboards;

class OnboardServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'onboard');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'onboard');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Zinginternal\Onboard\Providers\AuthServiceProvider::class);
        $this->app->register(\Zinginternal\Onboard\Providers\RouteServiceProvider::class);
        // $this->app->register(\Zinginternal\Onboard\Providers\EventServiceProvider::class);
        // $this->app->register(\Zinginternal\Onboard\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('zinginternal.onboard', function($app)
        {
            return $this->app->make(Onboards::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Onboard to repository
        $this->app->bind(
            'Zinginternal\Onboard\Interfaces\OnboardRepositoryInterface',
            \Zinginternal\Onboard\Repositories\Eloquent\OnboardRepository::class
        );
    }


    /**
     * Merges user's and onboard's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'zinginternal.onboard'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Zinginternal\Onboard\Commands\Onboard::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['zinginternal.onboard'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('zinginternal/onboard.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/onboard')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/onboard')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
